#!/usr/bin/env python

from __future__ import print_function
from GuiSetup import ScannerWindow
from PyQt4.QtGui import QApplication, QIcon
from PyQt4.QtCore import pyqtSlot

import datetime
import errno
import os
import pdb
import re
import sys
import traceback


def check_log_directory():
    try:
        os.mkdir(os.path.join(".", "Logs"))
    except OSError as e:
        if e.errno != errno.EEXIST:
            print("Error verifying \"Logs\" directory\nError {0}".format(str(e)))


def log_card_info(is_logging_in, **info):
    dt = datetime.datetime.now()
    filename = os.path.join(".", "Logs", r"{0:%Y-%m-%d}.txt".format(dt))

    if is_logging_in:
        text = "IN  {time:%H:%M:%S},{cardnum},{lastname},{firstname}\n".format(time=dt, **info)
    else:
        text = "OUT {time:%H:%M:%S},{cardnum},{lastname},{firstname}\n".format(time=dt, **info)

    print(text)
    
    try:
        with open(filename, "a", buffering=1) as f:
            f.write(text)
    except Exception as e:
        print("Error writing to log file {0}".format(filename, str(e)))
        traceback.print_exc()


@pyqtSlot(dict)
def card_added(info):
    log_card_info(True, **info)
    

@pyqtSlot(dict)
def card_removed(info):
    log_card_info(False, **info)


def main():
    check_log_directory()

    app = QApplication(sys.argv)

    window = ScannerWindow()
    window.setWindowTitle("CS Card Scanner")
    window.log_table.cardAdded.connect(card_added)
    window.log_table.cardRemoved.connect(card_removed)
    window.setWindowIcon(QIcon("icon.png"))
    window.show()

    app.exec_()


if __name__ == "__main__":
    main()
